mechanism to request queues before creating the device (vk_init_queue)
[vktest3] / src / vk.h
index 319fa99..3f765ac 100644 (file)
--- a/src/vk.h
+++ b/src/vk.h
@@ -10,14 +10,16 @@ enum {
        VKINIT_RAY              = 0x100
 };
 
/* queue capability flags for vk_find_qfamily */
 enum {
        VKQ_GFX                 = 1,
        VKQ_COMPUTE             = 2,
-       VKQ_PRESENT             = 4
+       VKQ_PRESENT             = 4,
+       VKQ_XFER                = 8
 };
 
 void vk_init_xwin(Display *dpy, Window win);
+void vk_init_queue(unsigned int qflags, int count);
 
 int vk_init(unsigned int flags, unsigned int *usedflags);
 void vk_cleanup(void);
@@ -10,14 +10,16 @@ enum {
 };
 
-/* queue capability flags for vk_find_qfamily */
+/* queue capability flags for vk_find_qfamily and vk_init_queue */
 enum {
        VKQ_GFX                 = 1,